.. raw:: html

    <p align="center">
        <a href="https://glia.rtfd.io"><img align="center" width="117" src="https://i.imgur.com/5jxLy6X.png"/></a>
    </p>
    <h4 align="center">G L I A</h4>
    <p align="center">
        Offical Desktop Client for Glial Engines
        <br>
    </p>
